"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = require("chalk");
const path = require("path");
const logic_1 = require("./logic");
/**
 * List of all Status Board components (widgets or jobs) within all available packages
 */
function list(args, options, logger, callback) {
    function parse(packages) {
        logger(`        Package "${path.basename(packages.dir)}":`);
        packages.items.forEach((item) => {
            logger(`          - ${chalk_1.default.gray(path.basename(item, '.js'))}`);
        });
    }
    const packagesLocalFolder = path.join(process.cwd(), '/packages');
    const packagesStatusBoardFolder = path.join(__dirname, '../../packages');
    const packagesPath = [packagesLocalFolder, packagesStatusBoardFolder];
    return logic_1.list(packagesPath, logger, (err, packages) => {
        if (err) {
            callback('Error reading package folder');
            return;
        }
        packages.forEach((packagez) => {
            logger(`Path: ${packagez.package}:
`);
            logger(chalk_1.default.yellow('  - Widgets:'));
            packagez.widgets.forEach(parse);
            logger(chalk_1.default.yellow('  - Jobs:'));
            packagez.jobs.forEach(parse);
        });
        logger('');
        callback();
    });
}
exports.list = list;
