"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = require("chalk");
const path = require("path");
const sanitizeFilename = require("sanitize-filename");
const logic_1 = require("./logic");
/**
 * Creates a new dashboard
 *
 * @params args[0] dashboard directory
 */
function newProject(args, options, logger, callback) {
    if (args.app.length < 1) {
        callback('Missing arguments. Please use "status-board new <mywallboard>"');
        return;
    }
    const newDirectory = sanitizeFilename(args.app);
    const srcDir = path.join(__dirname, '../..', 'templates', 'new-components', 'project');
    const destDir = path.join(process.cwd(), newDirectory);
    return logic_1.newProject(srcDir, destDir, logger, (error) => {
        if (error) {
            callback(error);
            return;
        }
        process.chdir(newDirectory);
        const isWindows = /^win/.test(process.platform);
        const npmCommand = isWindows ? 'npm.cmd' : 'npm';
        const childProcess = require('child_process');
        const child = childProcess.spawn(npmCommand, ['install', '--production'], { stdio: 'inherit' });
        logger('  Installing npm dependencies...');
        child.on('error', () => {
            // tslint:disable-next-line max-line-length
            logger('\n  Error installing dependencies. Please run "npm install" inside the dashboard directory');
            callback('Error installing dependencies');
        });
        child.on('exit', () => {
            logger([
                `${chalk_1.default.green('\n  SUCCESS !!')}
`,
                `  New project "${chalk_1.default.yellow(newDirectory)}" successfully created. Now you can:
`,
                chalk_1.default.gray(`   1. cd ${newDirectory}`),
                chalk_1.default.gray('   2. npm install'),
                chalk_1.default.gray('   3. start your server with `npm run start` (or `node start.js`)'),
                `${chalk_1.default.gray('   4. browse http://localhost:3000')}
`,
                '   Optionally: import the Atlassian package (or any other package) by running:\n',
                chalk_1.default.gray('   git init'),
                // tslint:disable-next-line max-line-length
                chalk_1.default.gray('   git submodule add https://bitbucket.org/atlassian/atlasboard-atlassian-package packages/atlassian\n'),
            ].join('\n'));
            callback();
        });
    });
}
exports.newProject = newProject;
