"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs");
const path = require("path");
const utilities_1 = require("../utilities");
const validNewDirectoryExp = /^[a-zA-Z0-9_-]*$/;
function newProject(srcDir, destDir, logger, callback) {
    // Check for valid directory name
    const dirName = path.basename(destDir);
    if (!dirName.match(validNewDirectoryExp)) {
        return callback('Invalid wallboard name');
    }
    if (!utilities_1.isPathContainedInRoot(destDir, process.cwd())) {
        return callback('invalid directory');
    }
    logger('\n  Generating a new Status Board project at %s...', destDir);
    const parentDir = path.dirname(destDir);
    if (utilities_1.directoryHasStatusBoardProject(parentDir)) {
        // tslint:disable-next-line max-line-length
        return callback('You can not create an Status Board inside a directory containing an Status Board (at least we think you shouldn\'t)');
    }
    if (fs.existsSync(destDir)) {
        // tslint:disable-next-line max-line-length
        return callback(`There is already a directory here called ${destDir}. Please choose a new name.`);
    }
    logger('  Creating new wallboard ...');
    const options = {
        data: {
            name: dirName,
        },
        engine: 'ejs',
    };
    utilities_1.scaffold(srcDir, destDir, options, callback);
}
exports.newProject = newProject;
