"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = require("chalk");
const logic_1 = require("./logic");
/**
 * When run in a project's base directory, starts the Status Board server.
 *
 * @params args[0] port (optional)
 * @params args --jobFilter filter by job (optional)
 * @params args --dashboardFilter filter by dashboard (optional)
 */
function start(args, options, logger, callback) {
    const port = isNaN(args.port) ? 3000 : args.port;
    const statusBoardOptions = { port, filters: {}, install: true };
    // const argsOptimistic = require('optimist')(args).argv;
    if (options.noinstall) {
        logger('Do not install dependencies');
        statusBoardOptions.install = false;
    }
    if (options.job) {
        logger(`Loading jobs matching ${chalk_1.default.yellow(options.job)} only`);
        statusBoardOptions.filters.jobFilter = options.job;
    }
    if (options.dashboard) {
        logger(`Loading dashboards matching ${chalk_1.default.yellow(options.dashboard)} only`);
        statusBoardOptions.filters.dashboardFilter = options.dashboard;
    }
    logger(chalk_1.default.gray('\nStarting server...'));
    logic_1.start(statusBoardOptions, logger, (err) => {
        callback(err);
    });
}
exports.start = start;
