"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const debug = require("debug");
const ejs = require("ejs");
const fs = require("fs");
const mkdirp = require("mkdirp");
const path = require("path");
const debugLog = debug('scaffolding');
const copyRecursiveSync = (src, dest, options) => {
    const exists = fs.existsSync(src);
    const isDirectory = exists ? fs.statSync(src).isDirectory() : false;
    if (exists && isDirectory) {
        debugLog('creating directory', dest);
        fs.mkdirSync(dest);
        fs.readdirSync(src).forEach((childItemName) => {
            debugLog('copying from', src, 'into', dest, 'File:', childItemName);
            copyRecursiveSync(path.join(src, childItemName), path.join(dest, childItemName), options);
        });
    }
    else {
        let output = fs.readFileSync(src).toString();
        if (options.engine === 'ejs') {
            output = ejs.render(output, options.data);
        }
        fs.writeFileSync(dest, output);
    }
};
/**
 * Folder scaffolding
 * @param  {string}   templateSourceFolder Templating source
 * @param  {string}   destinationFolder    Destination folder
 * @param  {object}   options (optional)
 *                    options.engine : templating engine ('ejs')
 *                    options.replace : object with replacement options
 * @param  {Function} cb                   Callback (err, null);
 */
function scaffold(templateSourceFolder, destinationFolder, options, cb) {
    mkdirp(path.dirname(destinationFolder), (err) => {
        if (err) {
            return cb(err);
        }
        copyRecursiveSync(templateSourceFolder, destinationFolder, options);
        cb();
    });
}
exports.scaffold = scaffold;
